@@ -29,9 +29,6 @@ RECONNECT_INTERVAL = 1
 # worker的env
 WORKER_ENV_KEY = 'MAPLE_WORKER'
 
-# 网络连接超时(秒)，包括 connect once，read once，write once
-CONN_TIMEOUT = 3
-
 # write_to_users / close_users 时的特殊连接集合
 CONNS_AUTHED                = -1 # 所有已登录连接
 CONNS_ALL                   = -2 # 所有连接
