@@ -230,3 +230,5 @@ class Connection(object):
         """
         return self.client.closed()
 
+    def shutdown(self, how=2):
+        return self.client.shutdown(how)
